==> WufooR_0.5.5.tar.gz: WufooR/README.md <==
[![Build Status](https://travis-ci.org/dmpe/WufooR.svg?branch=master)](https://travis-ci.org/dmpe/WufooR)
[![Coverage Status](https://coveralls.io/repos/dmpe/WufooR/badge.svg?branch=master&service=github)](https://coveralls.io/github/dmpe/WufooR?branch=master)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/WufooR)](http://cran.r-project.org/package=WufooR)

R package for Wufoo API
=======

This package doesn't support creating new forms. It can be only used to retrieve information about your form entries. 

### Installing (not yet on CRAN)

Use `devtools` to install the latest version from Github:

```
library(devtools)
devtools::install_github("dmpe/wufoor")
```

Tested on Ubuntu 15.04 and Windows 10 (64 bit using R 3.2.1)

### Looking for examples and current implementation status ?

Check the vignette in `vignettes` folder.

### How to contribute 

- Fork the repository
- Create and switch to a new branch `git checkout -b [name_of_your_new_branch]`
- Do the changes (i.e. edit files)
- Push remote branch to your github `git remote add -t [name_of_your_remote]` & `git push -u origin [name_of_your_remote]`
- Create a new pull request (to my `master` branch)

Want a direct push access? No problem, just let me know and become a :family:.

**Also**:
 - Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.

### Developed by:

- [@dmpe](https://www.github.com/dmpe) :yum:.

## Meta
- Licensed under [Apache License 2.0](https://tldrlegal.com/license/apache-license-2.0-%28apache-2.0%29).
- Please report bugs in <https://github.com/dmpe/wufoor/issues>.

==> WufooR_0.5.9.tar.gz: WufooR/README.md <==
[![Build Status](https://travis-ci.org/dmpe/WufooR.svg?branch=master)](https://travis-ci.org/dmpe/WufooR)
[![Coverage Status](https://coveralls.io/repos/dmpe/WufooR/badge.svg?branch=master&service=github)](https://coveralls.io/github/dmpe/WufooR?branch=master)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/WufooR)](http://cran.r-project.org/package=WufooR)

R package for Wufoo API
=======

This package doesn't support creating new forms. It can be only used to retrieve information about your form entries. 

### Installing (not yet on CRAN)

Use `devtools` to install the latest version from Github:

```
library(devtools)
devtools::install_github("dmpe/wufoor")
```

Tested on Ubuntu 15.10 and Windows 10 (64 bit using latest R)

### Looking for examples and current implementation status ?

Check the vignette in `vignettes` folder.

### How to contribute 

- Fork the repository
- Create and switch to a new branch `git checkout -b [name_of_your_new_branch]`
- Do the changes (i.e. edit files)
- Push remote branch to your github `git remote add -t [name_of_your_remote]` & `git push -u origin [name_of_your_remote]`
- Create a new pull request (to my `master` branch)

Want a direct push access? No problem, just let me know and become a :family:.

**Also**:
 - Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.

### Developed by:

- [@dmpe](https://www.github.com/dmpe) :yum:.

## Meta
- Licensed under [Apache License 2.0](https://tldrlegal.com/license/apache-license-2.0-%28apache-2.0%29).
- Please report bugs in <https://github.com/dmpe/wufoor/issues>.
